# Util.pm (HCT::Util)
#
# Copyright 2008, 2009
# Slade Maurer
#
# This file is part of HCT, the Hardware Complexity Tool
#
# HCT is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# HCT is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public License
# along with HCT.  If not, see <http://www.gnu.org/licenses/>.

=head1 NAME

HCT::Util - Generic utility functions for HCT.

=head1 DESCRIPTION

This package contains various utility functions which do not belong anywhere
else.

=cut

package HCT::Util;

our $VERSION = '1.0';

use strict;
use warnings;

require Exporter;
our @ISA    = qw(Exporter);
our @EXPORT = qw(
	reduce_string
);

=head1 FUNCTIONS

This package provides several types of routines:

=head2 Strings

=over 4

=cut


=item B<reduce_string (STRING [, REQUIRED_LENGTH, [, REPLACEMENT]])>

Reduces string from the center and substitutes this place. REQUIRED_LENGTH means, 
what length should have incoming string after substitution. By default the 
replacement part equal to '~'.

	print reduce_string ('operator_precedence_sub', 11);
	# the result: opera~e_sub

=cut

sub reduce_string (@)
{
	my $str = shift;
	return '' unless defined $str;
	my $required_length = shift || 0;
	my $replacement = shift || '~';
	my $strlen = length ($str);

	if ($required_length < 1
		|| $strlen < 1
		|| $strlen <= $required_length){
		return $str;
	}

	my $offset = int (($required_length - length ($replacement)) / 2);
	my $length = $strlen - $offset * 2;
	my $correction = (($offset * 2 + length ($replacement)) < $required_length) ? 1 : 0;

	substr (
		$str,
		$offset + $correction,
		$length - $correction,
		$replacement
	);

	return $str;
}

=back

=cut

1;

