# vhdl.pm (HCT::lang::hdl::vhdl)
#
# Copyright 2008, 2009
# Slade Maurer
#
# This file is part of HCT, the Hardware Complexity Tool
#
# HCT is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# HCT is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public License
# along with HCT.  If not, see <http://www.gnu.org/licenses/>.

=head1 NAME

HCT::lang::hdl::vhdl - Class of VHDL language. 

=head1 DESCRIPTION

VHDL (VHSIC (Very High Speed Integrated Circuits) hardware description language) is 
commonly used as a design-entry language for field-programmable gate arrays and 
application-specific integrated circuits in electronic design automation of digital circuits.

=head1 DESIGN

VHDL is a fairly general-purpose language, and it doesn't require a simulator on which to run 
the code. There are a lot of VHDL compilers, which build executable binaries. It can read and 
write files on the host computer, so a VHDL program can be written that generates another VHDL 
program to be incorporated in the design being developed. Because of this general-purpose nature, 
it is possible to use VHDL to write a testbench that verifies the functionality of the design 
using files on the host computer to define stimuli, interacts with the user, and compares results 
with those expected. VHDL is a strongly typed language.

=cut

package HCT::lang::hdl::vhdl;

# Use base object for creating a new language.
use base 'HCT::Lang::LangDriver';

use strict;
use warnings;

require HCT::lang::hdl::vhdl::lexer;
require HCT::lang::hdl::vhdl::parser;

our @FILE_ASSOCIATIONS = ('vhdl');

our %OUTPUT_METRICS = ('MCCABE',0,'IO',0,'NET',0,'TIME',0,'SLOC',0,'COMMENT_LINES',0);
our %OUTPUT_LEVELS = (
	'TERMINAL' => [
		[  0 , undef],
		[ 72 , [[4,'IO'],[5,'NET'],[8,'MCCABE'],[6,'TIME']] ],
		[ 72 , [[6,'SLOC'],[15,'COMMENT_LINES'],[6,'TIME']]],
	],
	'CSV' => [
		[  0 , undef],
		[ 99 , [[4,'IO'],[5,'NET'],[8,'MCCABE'],[6,'SLOC'],[15,'COMMENT_LINES'],[6,'TIME']] ],	
	],
);

sub new
{
	my $class = shift;
	my $self = $class->SUPER::new (@_);

	$self->parser (new HCT::lang::hdl::vhdl::parser);
	$self->lexer (new HCT::lang::hdl::vhdl::lexer);

	$self->output->metrics (\%OUTPUT_METRICS);
	$self->output->levels  (\%OUTPUT_LEVELS);

	return $self; 
}

1;
